@@ -4,13 +4,17 @@
 package dao
 
 import (
+	"bytes"
+	"context"
 	"fmt"
+	"log/slog"
 	"strings"
 
+	"github.com/derailed/k9s/internal/slogs"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
-	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/cli-runtime/pkg/printers"
 )
 
 // Secret represents a secret K8s resource.
@@ -25,11 +29,54 @@ func (s *Secret) Describe(path string) (string, error) {
 	if err != nil {
 		return "", err
 	}
-	if !s.decodeData {
-		return encodedDescription, nil
+	if s.decodeData {
+		return s.Decode(encodedDescription, path)
 	}
 
-	return s.Decode(encodedDescription, path)
+	return encodedDescription, nil
+}
+
+// ToYAML returns a resource yaml.
+func (s *Secret) ToYAML(path string, showManaged bool) (string, error) {
+	if s.decodeData {
+		return s.decodeYAML(path, showManaged)
+	}
+
+	return s.Generic.ToYAML(path, showManaged)
+}
+
+func (s *Secret) decodeYAML(path string, showManaged bool) (string, error) {
+	o, err := s.Get(context.Background(), path)
+	if err != nil {
+		return "", err
+	}
+	o = o.DeepCopyObject()
+	u, ok := o.(*unstructured.Unstructured)
+	if !ok {
+		return "", fmt.Errorf("expecting unstructured but got %T", o)
+	}
+	if u.Object == nil {
+		return "", fmt.Errorf("expecting unstructured object but got nil")
+	}
+	if !showManaged {
+		if meta, ok := u.Object["metadata"].(map[string]any); ok {
+			delete(meta, "managedFields")
+		}
+	}
+	if decoded, err := ExtractSecrets(o); err == nil {
+		u.Object["data"] = decoded
+	}
+
+	var (
+		buff bytes.Buffer
+		p    printers.YAMLPrinter
+	)
+	if err := p.PrintObj(o, &buff); err != nil {
+		slog.Error("PrintObj failed", slogs.Error, err)
+		return "", err
+	}
+
+	return buff.String(), nil
 }
 
 // SetDecodeData toggles decode mode.
@@ -40,11 +87,6 @@ func (s *Secret) SetDecodeData(b bool) {
 // Decode removes the encoded part from the secret's description and appends the
 // secret's decoded data.
 func (s *Secret) Decode(encodedDescription, path string) (string, error) {
-	o, err := s.getFactory().Get(s.gvr, path, true, labels.Everything())
-	if err != nil {
-		return "", err
-	}
-
 	dataEndIndex := strings.Index(encodedDescription, "====")
 	if dataEndIndex == -1 {
 		return "", fmt.Errorf("unable to find data section in secret description")
@@ -59,11 +101,14 @@ func (s *Secret) Decode(encodedDescription, path string) (string, error) {
 	// More details about the reasoning of index: https://github.com/kubernetes/kubectl/blob/v0.29.0/pkg/describe/describe.go#L2542
 	body := encodedDescription[0:dataEndIndex]
 
+	o, err := s.Get(context.Background(), path)
+	if err != nil {
+		return "", err
+	}
 	data, err := ExtractSecrets(o)
 	if err != nil {
 		return "", err
 	}
-
 	decodedSecrets := make([]string, 0, len(data))
 	for k, v := range data {
 		line := fmt.Sprintf("%s: %s", k, v)
@@ -88,7 +133,6 @@ func ExtractSecrets(o runtime.Object) (map[string]string, error) {
 	if err != nil {
 		return nil, err
 	}
-
 	secretData := make(map[string]string, len(secret.Data))
 	for k, val := range secret.Data {
 		secretData[k] = string(val)
