@@ -8,9 +8,9 @@ import (
 	"errors"
 	"fmt"
 	"log/slog"
+	"maps"
 	"os"
 	"os/signal"
-	"runtime"
 	"sort"
 	"strings"
 	"sync/atomic"
@@ -93,15 +93,15 @@ func (a *App) ConOK() bool {
 }
 
 // Init initializes the application.
-func (a *App) Init(version string, rate int) error {
+func (a *App) Init(version string, _ int) error {
 	a.version = model.NormalizeVersion(version)
 
 	ctx := context.WithValue(context.Background(), internal.KeyApp, a)
 	if err := a.Content.Init(ctx); err != nil {
 		return err
 	}
-	a.Content.Stack.AddListener(a.Crumbs())
-	a.Content.Stack.AddListener(a.Menu())
+	a.Content.AddListener(a.Crumbs())
+	a.Content.AddListener(a.Menu())
 
 	a.App.Init()
 	a.SetInputCapture(a.keyboard)
@@ -139,7 +139,7 @@ func (a *App) Init(version string, rate int) error {
 	return nil
 }
 
-func (a *App) stopImgScanner() {
+func (*App) stopImgScanner() {
 	if vul.ImgScanner != nil {
 		vul.ImgScanner.Stop()
 	}
@@ -167,11 +167,13 @@ func (a *App) layout(ctx context.Context) {
 	main.AddItem(flash, 1, 1, false)
 
 	a.Main.AddPage("main", main, true, false)
-	a.Main.AddPage("splash", ui.NewSplash(a.Styles, a.version), true, true)
 	a.toggleHeader(!a.Config.K9s.IsHeadless(), !a.Config.K9s.IsLogoless())
+	if !a.Config.K9s.IsSplashless() {
+		a.Main.AddPage("splash", ui.NewSplash(a.Styles, a.version), true, true)
+	}
 }
 
-func (a *App) initSignals() {
+func (*App) initSignals() {
 	sig := make(chan os.Signal, 1)
 	signal.Notify(sig, syscall.SIGHUP)
 
@@ -196,8 +198,8 @@ func (a *App) suggestCommand() model.SuggestionFunc {
 		}
 
 		ls := strings.ToLower(s)
-		for _, k := range a.command.alias.Aliases.Keys() {
-			if suggest, ok := cmd.ShouldAddSuggest(ls, k); ok {
+		for alias := range maps.Keys(a.command.alias.Alias) {
+			if suggest, ok := cmd.ShouldAddSuggest(ls, alias); ok {
 				entries = append(entries, suggest)
 			}
 		}
@@ -238,9 +240,8 @@ func (a *App) keyboard(evt *tcell.EventKey) *tcell.EventKey {
 
 func (a *App) bindKeys() {
 	a.AddActions(ui.NewKeyActionsFromMap(ui.KeyMap{
-		ui.KeyShift9:       ui.NewSharedKeyAction("DumpGOR", a.dumpGOR, false),
 		tcell.KeyCtrlE:     ui.NewSharedKeyAction("ToggleHeader", a.toggleHeaderCmd, false),
-		tcell.KeyCtrlG:     ui.NewSharedKeyAction("toggleCrumbs", a.toggleCrumbsCmd, false),
+		tcell.KeyCtrlG:     ui.NewSharedKeyAction("ToggleCrumbs", a.toggleCrumbsCmd, false),
 		ui.KeyHelp:         ui.NewSharedKeyAction("Help", a.helpCmd, false),
 		ui.KeyLeftBracket:  ui.NewSharedKeyAction("Go Back", a.previousCommand, false),
 		ui.KeyRightBracket: ui.NewSharedKeyAction("Go Forward", a.nextCommand, false),
@@ -251,15 +252,6 @@ func (a *App) bindKeys() {
 	}))
 }
 
-func (a *App) dumpGOR(evt *tcell.EventKey) *tcell.EventKey {
-	slog.Debug("GOR", slogs.GOR, runtime.NumGoroutine())
-	bb := make([]byte, 5_000_000)
-	runtime.Stack(bb, true)
-	slog.Debug("GOR stack", slogs.Stack, string(bb))
-
-	return evt
-}
-
 // ActiveView returns the currently active view.
 func (a *App) ActiveView() model.Component {
 	return a.Content.GetPrimitive("main").(model.Component)
@@ -399,7 +391,7 @@ func (a *App) refreshCluster(context.Context) error {
 		c.Stop()
 	}
 
-	count, maxConnRetry := atomic.LoadInt32(&a.conRetry), int32(a.Config.K9s.MaxConnRetry)
+	count, maxConnRetry := atomic.LoadInt32(&a.conRetry), a.Config.K9s.MaxConnRetry
 	if count >= maxConnRetry {
 		slog.Error("Conn check failed. Bailing out!",
 			slogs.Retry, count,
@@ -463,7 +455,7 @@ func (a *App) switchContext(ci *cmd.Interpreter, force bool) error {
 		p := cmd.NewInterpreter(a.Config.ActiveView())
 		p.ResetContextArg()
 		if p.IsContextCmd() {
-			a.Config.SetActiveView("pod")
+			a.Config.SetActiveView(client.PodGVR.String())
 		}
 		ns := a.Config.ActiveNamespace()
 		if !a.Conn().IsValidNamespace(ns) {
@@ -523,7 +515,9 @@ func (a *App) Run() error {
 	a.Resume()
 
 	go func() {
-		<-time.After(splashDelay)
+		if !a.Config.K9s.IsSplashless() {
+			<-time.After(splashDelay)
+		}
 		a.QueueUpdateDraw(func() {
 			a.Main.SwitchToPage("main")
 			// if command bar is already active, focus it
@@ -597,7 +591,7 @@ func (a *App) setIndicator(l model.FlashLevel, msg string) {
 }
 
 // PrevCmd pops the command stack.
-func (a *App) PrevCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (a *App) PrevCmd(*tcell.EventKey) *tcell.EventKey {
 	if !a.Content.IsLast() {
 		a.Content.Pop()
 	}
@@ -642,7 +636,8 @@ func (a *App) gotoCmd(evt *tcell.EventKey) *tcell.EventKey {
 }
 
 func (a *App) cowCmd(msg string) {
-	dialog.ShowError(a.Styles.Dialog(), a.Content.Pages, msg)
+	d := a.Styles.Dialog()
+	dialog.ShowError(&d, a.Content.Pages, msg)
 }
 
 func (a *App) dirCmd(path string, pushCmd bool) error {
@@ -665,15 +660,18 @@ func (a *App) dirCmd(path string, pushCmd bool) error {
 }
 
 func (a *App) quitCmd(evt *tcell.EventKey) *tcell.EventKey {
+	noExit := a.Config.K9s.NoExitOnCtrlC
 	if a.InCmdMode() {
+		if isBailoutEvt(evt) && noExit {
+			return nil
+		}
 		return evt
 	}
 
-	if !a.Config.K9s.NoExitOnCtrlC {
+	if !noExit {
 		a.BailOut(0)
 	}
 
-	// overwrite the default ctrl-c behavior of tview
 	return nil
 }
 
@@ -701,12 +699,12 @@ func (a *App) previousCommand(evt *tcell.EventKey) *tcell.EventKey {
 	if evt != nil && evt.Rune() == rune(ui.KeyLeftBracket) && a.Prompt().InCmdMode() {
 		return evt
 	}
-	cmds := a.cmdHistory.List()
-	if !a.cmdHistory.Back() {
+	c, ok := a.cmdHistory.Back()
+	if !ok {
 		a.App.Flash().Warn("Can't go back any further")
 		return evt
 	}
-	a.gotoResource(cmds[a.cmdHistory.CurrentIndex()], "", true, false)
+	a.gotoResource(c, "", true, false)
 	return nil
 }
 
@@ -715,14 +713,14 @@ func (a *App) nextCommand(evt *tcell.EventKey) *tcell.EventKey {
 	if evt != nil && evt.Rune() == rune(ui.KeyRightBracket) && a.Prompt().InCmdMode() {
 		return evt
 	}
-	cmds := a.cmdHistory.List()
-	if !a.cmdHistory.Forward() {
+	c, ok := a.cmdHistory.Forward()
+	if !ok {
 		a.App.Flash().Warn("Can't go forward any further")
 		return evt
 	}
 	// We go to the resource before updating the history so that
 	// gotoResource doesn't add this command to the history
-	a.gotoResource(cmds[a.cmdHistory.CurrentIndex()], "", true, false)
+	a.gotoResource(c, "", true, false)
 	return nil
 }
 
@@ -731,34 +729,34 @@ func (a *App) lastCommand(evt *tcell.EventKey) *tcell.EventKey {
 	if evt != nil && evt.Rune() == ui.KeyDash && a.Prompt().InCmdMode() {
 		return evt
 	}
-	cmds := a.cmdHistory.List()
-	if len(cmds) < 1 {
+	c, ok := a.cmdHistory.Top()
+	if !ok {
 		a.App.Flash().Warn("No previous view to switch to")
 		return evt
-	} else {
-		a.cmdHistory.Last()
-		a.gotoResource(cmds[a.cmdHistory.CurrentIndex()], "", true, false)
 	}
+	a.gotoResource(c, "", true, false)
+
 	return nil
 }
 
-func (a *App) aliasCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (a *App) aliasCmd(*tcell.EventKey) *tcell.EventKey {
 	if a.Content.Top() != nil && a.Content.Top().Name() == aliasTitle {
 		a.Content.Pop()
 		return nil
 	}
 
-	if err := a.inject(NewAlias(client.NewGVR("aliases")), false); err != nil {
+	if err := a.inject(NewAlias(client.AliGVR), false); err != nil {
 		a.Flash().Err(err)
 	}
 
 	return nil
 }
 
-func (a *App) gotoResource(c, path string, clearStack bool, pushCmd bool) {
+func (a *App) gotoResource(c, path string, clearStack, pushCmd bool) {
 	err := a.command.run(cmd.NewInterpreter(c), path, clearStack, pushCmd)
 	if err != nil {
-		dialog.ShowError(a.Styles.Dialog(), a.Content.Pages, err.Error())
+		d := a.Styles.Dialog()
+		dialog.ShowError(&d, a.Content.Pages, err.Error())
 	}
 }
 
@@ -772,7 +770,7 @@ func (a *App) inject(c model.Component, clearStack bool) error {
 		return err
 	}
 	if clearStack {
-		a.Content.Stack.Clear()
+		a.Content.Clear()
 	}
 	a.Content.Push(c)
 
