@@ -12,6 +12,7 @@ import (
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/ui"
+	"github.com/derailed/k9s/internal/ui/dialog"
 	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
@@ -28,7 +29,7 @@ type Context struct {
 }
 
 // NewContext returns a new viewer.
-func NewContext(gvr client.GVR) ResourceViewer {
+func NewContext(gvr *client.GVR) ResourceViewer {
 	c := Context{
 		ResourceViewer: NewBrowser(gvr),
 	}
@@ -40,7 +41,14 @@ func NewContext(gvr client.GVR) ResourceViewer {
 
 func (c *Context) bindKeys(aa *ui.KeyActions) {
 	aa.Delete(ui.KeyShiftA, tcell.KeyCtrlSpace, ui.KeySpace)
+	if !c.App().Config.IsReadOnly() {
+		c.bindDangerousKeys(aa)
+	}
+}
+
+func (c *Context) bindDangerousKeys(aa *ui.KeyActions) {
 	aa.Add(ui.KeyR, ui.NewKeyAction("Rename", c.renameCmd, true))
+	aa.Add(tcell.KeyCtrlD, ui.NewKeyAction("Delete", c.deleteCmd, true))
 }
 
 func (c *Context) renameCmd(evt *tcell.EventKey) *tcell.EventKey {
@@ -54,6 +62,24 @@ func (c *Context) renameCmd(evt *tcell.EventKey) *tcell.EventKey {
 	return nil
 }
 
+func (c *Context) deleteCmd(evt *tcell.EventKey) *tcell.EventKey {
+	contextName := c.GetTable().GetSelectedItem()
+	if contextName == "" {
+		return evt
+	}
+
+	d := c.App().Styles.Dialog()
+	dialog.ShowConfirm(&d, c.App().Content.Pages, "Delete", fmt.Sprintf("Delete context %q?", contextName), func() {
+		if err := c.App().factory.Client().Config().DelContext(contextName); err != nil {
+			c.App().Flash().Err(err)
+			return
+		}
+		c.Refresh()
+	}, func() {})
+
+	return nil
+}
+
 func (c *Context) renameDialogCallback(form *tview.Form, contextName string) error {
 	app := c.App()
 	input := form.GetFormItemByLabel(inputField).(*tview.InputField)
@@ -85,25 +111,25 @@ func (c *Context) showRenameModal(name string, ok func(form *tview.Form, context
 			app.Content.Pages.RemovePage(renamePage)
 		}).
 		AddButton("Cancel", func() {
-			app.Content.Pages.RemovePage(renamePage)
+			app.Content.RemovePage(renamePage)
 		})
 
 	m := tview.NewModalForm("<Rename>", f)
 	m.SetText(fmt.Sprintf("Rename context %q?", name))
 	m.SetDoneFunc(func(int, string) {
-		app.Content.Pages.RemovePage(renamePage)
+		app.Content.RemovePage(renamePage)
 	})
-	app.Content.Pages.AddPage(renamePage, m, false, false)
-	app.Content.Pages.ShowPage(renamePage)
+	app.Content.AddPage(renamePage, m, false, false)
+	app.Content.ShowPage(renamePage)
 
-	for i := 0; i < f.GetButtonCount(); i++ {
+	for i := range f.GetButtonCount() {
 		f.GetButton(i).
 			SetBackgroundColorActivated(styles.ButtonFocusBgColor.Color()).
 			SetLabelColorActivated(styles.ButtonFocusFgColor.Color())
 	}
 }
 
-func (c *Context) useCtx(app *App, model ui.Tabular, gvr client.GVR, path string) {
+func (c *Context) useCtx(app *App, _ ui.Tabular, gvr *client.GVR, path string) {
 	slog.Debug("Using context",
 		slogs.GVR, gvr,
 		slogs.FQN, path,
@@ -120,7 +146,7 @@ func useContext(app *App, name string) error {
 	if app.Content.Top() != nil {
 		app.Content.Top().Stop()
 	}
-	res, err := dao.AccessorFor(app.factory, client.NewGVR("contexts"))
+	res, err := dao.AccessorFor(app.factory, client.CtGVR)
 	if err != nil {
 		return err
 	}
