@@ -63,9 +63,9 @@ func NewLiveView(app *App, title string, m model.ResourceViewer) *LiveView {
 	return &v
 }
 
-func (*LiveView) SetCommand(*cmd.Interpreter)      {}
-func (*LiveView) SetFilter(string)                 {}
-func (*LiveView) SetLabelSelector(labels.Selector) {}
+func (*LiveView) SetCommand(*cmd.Interpreter)            {}
+func (*LiveView) SetFilter(string, bool)                 {}
+func (*LiveView) SetLabelSelector(labels.Selector, bool) {}
 
 // Init initializes the viewer.
 func (v *LiveView) Init(_ context.Context) error {
@@ -162,14 +162,13 @@ func (v *LiveView) bindKeys() {
 	if v.title == yamlAction {
 		v.actions.Add(ui.KeyM, ui.NewKeyAction("Toggle ManagedFields", v.toggleManagedCmd, true))
 	}
-	if v.model != nil && v.model.GVR().IsDecodable() {
+	if _, ok := v.model.(model.EncDecResourceViewer); ok {
 		v.actions.Add(ui.KeyX, ui.NewKeyAction("Toggle Decode", v.toggleEncodedDecodedCmd, true))
 	}
 }
 
 func (v *LiveView) toggleEncodedDecodedCmd(evt *tcell.EventKey) *tcell.EventKey {
 	m, ok := v.model.(model.EncDecResourceViewer)
-
 	if !ok {
 		return evt
 	}
